
`timescale 100 ps/100 ps

module Gowin_EMPU_template (
 sys_clk,
 gpio,
 uart0_rxd,
 uart0_txd,
 reset_n
 );
 
input sys_clk;
inout [15:0] gpio;
input uart0_rxd;
output uart0_txd;
input reset_n;


//AHB2 Master
wire master_hclk ;
wire master_hrst ;
wire master_hsel ;
wire [31:0] master_haddr ;
wire [1:0] master_htrans ;
wire master_hwrite ;
wire [2:0] master_hsize ;
wire [2:0] master_hburst ;
wire [3:0] master_hprot ;
wire [1:0] master_memattr ;//
wire master_exreq ;//
wire [3:0] master_hmaster ;
wire [31:0] master_hwdata ;
wire master_hmastlock ;
wire master_hreadymux ;
wire master_hauser ;//
wire [3:0] master_hwuser ;//
wire [31:0] master_hrdata ;
wire master_hreadyout ;
wire master_hresp ;
wire master_exresp ;//
wire [2:0] master_hruser ;//

Gowin_AHB_Multiple u_ahb_multiple
(
 .AHB_HRDATA(master_hrdata),
 .AHB_HREADY(master_hreadyout),//ready signal, slave to MCU master, 1'b1
 .AHB_HRESP(master_hresp),//respone signal, slave to MCU master
 .AHB_HTRANS(master_htrans),
 .AHB_HBURST(master_hburst),
 .AHB_HPROT(master_hprot),
 .AHB_HSIZE(master_hsize),
 .AHB_HWRITE(master_hwrite),
 .AHB_HMASTLOCK(master_hmastlock),
 .AHB_HMASTER(master_hmaster),
 .AHB_HADDR(master_haddr[11:0]),
 .AHB_HWDATA(master_hwdata),
 .AHB_HSEL(master_hsel),
 .AHB_HCLK(master_hclk),
 .AHB_HRESETn(master_hrst)
);


//APB2 Master [1]
wire        master_pclk;
wire        master_rst;
wire        master_penable;
wire [7:0]  master_paddr;
wire        master_pwrite;
wire [31:0] master_pwdata;
wire [3:0]  master_pstrb;
wire [2:0]  master_pprot;
wire        master_psel1;
wire [31:0] master_prdata1;
wire        master_pready1;
wire        master_pslverr1;
wire        psel_valid_es1;
wire        penable_valid_es1;

Gowin_APB2_Multiple multiple_template (
 .pclk(master_pclk), 
 .presetn(master_rst),
 .psel(psel_valid_es1), 
 .penable(penable_valid_es1),
 .pwrite(master_pwrite), 
 .paddr({4'b0000,master_paddr[7:2]}),  
 .pwdata(master_pwdata), 
 .prdata(master_prdata1)
);

Gowin_APB2_Decoder 
    #(.ADDR_WIDTH(8))
 u_multiple_1(
     .paddr_i        ({24'h0,master_paddr[7:0]}),
	 .penable_i      (master_penable           ),
	 .pprot_i        (master_pprot[0]          ),
	 .secure_i       (1'b0                     ),
	 .pready_i       (1'b1                     ),
	 .psel_valid_o   (psel_valid_es1           ),//decoded psel to slave
     .penable_valid_o(penable_valid_es1        ),//decoded penable to slave
     .pready_o       (master_pready1           ),
     .psel_i         (master_psel1             )
  );


//Gowin_EMPU_Top instance
Gowin_EMPU_Top u_Gowin_EMPU_Top (
 .sys_clk(sys_clk),
 .gpio(gpio),
 .uart0_rxd(uart0_rxd),
 .uart0_txd(uart0_txd),
 .master_hclk(master_hclk),
 .master_hrst(master_hrst),
 .master_hsel(master_hsel),
 .master_haddr(master_haddr),
 .master_htrans(master_htrans),
 .master_hwrite(master_hwrite),
 .master_hsize(master_hsize),
 .master_hburst(master_hburst),
 .master_hprot(master_hprot),
 .master_memattr(master_memattr),
 .master_exreq(master_exreq),
 .master_hmaster(master_hmaster),
 .master_hwdata(master_hwdata),
 .master_hmastlock(master_hmastlock),
 .master_hreadymux(master_hreadymux),
 .master_hauser(master_hauser),
 .master_hwuser(master_hwuser),
 .master_hrdata(master_hrdata),
 .master_hreadyout(master_hreadyout),
 .master_hresp(master_hresp),
 .master_exresp(master_exresp),
 .master_hruser(master_hruser),
 .master_pclk(master_pclk),
 .master_rst(master_rst),
 .master_penable(master_penable),
 .master_paddr(master_paddr),
 .master_pwrite(master_pwrite),
 .master_pwdata(master_pwdata),
 .master_pstrb(master_pstrb),
 .master_pprot(master_pprot),
 .master_psel1(master_psel1),
 .master_prdata1(master_prdata1),
 .master_pready1(master_pready1),
 .master_pslverr1(master_pslverr1),
 .reset_n(reset_n)
);

endmodule