
//Gowin_EMPU(GW1NS-2C) + AHB PSRAM
//GW1NSR-2C

module Gowin_EMPU_Template (
  sys_clk,
  uart0_rxd,
  uart0_txd,
  reset_n,
  init_calib,   //initialized flag
  O_psram_ck,
  O_psram_ck_n,
  O_psram_cs_n,
  O_psram_reset_n,
  IO_psram_dq,
  IO_psram_rwds
);

input sys_clk;
input uart0_rxd;
output uart0_txd;
input reset_n;
output init_calib;
output [0:0] O_psram_ck;
output [0:0] O_psram_ck_n;
output [0:0] O_psram_cs_n;
output [0:0] O_psram_reset_n;
inout [7:0] IO_psram_dq;
inout [0:0] IO_psram_rwds;

wire master_hclk;
wire master_hrst;
wire master_hsel;
wire [31:0] master_haddr;
wire [1:0] master_htrans;
wire master_hwrite;
wire [2:0] master_hsize;
wire [2:0] master_hburst;
wire [3:0] master_hprot;
wire [1:0] master_memattr;
wire master_exreq;
wire [3:0] master_hmaster;
wire [31:0] master_hwdata;
wire master_hmastlock;
wire master_hreadymux;
wire master_hauser;
wire [3:0] master_hwuser;
wire [31:0] master_hrdata;
wire master_hreadyout;
wire master_hresp;
wire master_exresp;
wire [2:0] master_hruser;

//AHB PSRAM instantiation
Gowin_AHB_PSRAM_Top u_Gowin_AHB_PSRAM_Top (
  .AHB_HRDATA(master_hrdata),
  .AHB_HREADY(master_hreadyout),
  .AHB_HRESP(master_hresp),
  .AHB_HTRANS(master_htrans),
  .AHB_HBURST(master_hburst),
  .AHB_HPROT(master_hprot),
  .AHB_HSIZE(master_hsize),
  .AHB_HWRITE(master_hwrite),
  .AHB_HMASTLOCK(master_hmastlock),
  .AHB_HMASTER(master_hmaster),
  .AHB_HADDR(master_haddr),
  .AHB_HWDATA(master_hwdata),
  .AHB_HSEL(master_hsel),
  .AHB_HCLK(master_hclk),
  .AHB_HRESETn(master_hrst),
  .psram_base_clk(master_hclk), //25MHz
  .psram_memory_clk(sys_clk),   //50MHz
  .led_init(init_calib),
  .O_psram_ck(O_psram_ck),
  .O_psram_ck_n(O_psram_ck_n),
  .O_psram_cs_n(O_psram_cs_n),
  .O_psram_reset_n(O_psram_reset_n),
  .IO_psram_dq(IO_psram_dq),
  .IO_psram_rwds(IO_psram_rwds)
);


//Gowin_EMPU_Top instantiation
Gowin_EMPU_Top u_Gowin_EMPU_Top(
  .sys_clk(sys_clk),    //25MHz
  .uart0_rxd(uart0_rxd),
  .uart0_txd(uart0_txd),
  .master_hclk(master_hclk),
  .master_hrst(master_hrst),
  .master_hsel(master_hsel),
  .master_haddr(master_haddr),
  .master_htrans(master_htrans),
  .master_hwrite(master_hwrite),
  .master_hsize(master_hsize),
  .master_hburst(master_hburst),
  .master_hprot(master_hprot),
  .master_memattr(master_memattr),
  .master_exreq(master_exreq),
  .master_hmaster(master_hmaster),
  .master_hwdata(master_hwdata),
  .master_hmastlock(master_hmastlock),
  .master_hreadymux(master_hreadymux),
  .master_hauser(master_hauser),
  .master_hwuser(master_hwuser),
  .master_hrdata(master_hrdata),
  .master_hreadyout(master_hreadyout),
  .master_hresp(master_hresp),
  .master_exresp(master_exresp),
  .master_hruser(master_hruser),
  .reset_n(reset_n)
);

endmodule