
/*
 * *****************************************************************************************
 *
 * 		Copyright (C) 2014-2020 Gowin Semiconductor Technology Co.,Ltd.
 * 		
 * @file			main.c
 * @author		Embedded Development Team
 * @version		V1.4.0
 * @date			2020-5-1 09:00:00
 * @brief			Main program body.
 ******************************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include <stdio.h>
#include <string.h>

#include "gw1ns2c.h"
#include "gowin_psram.h"

/* Macros ------------------------------------------------------------------*/
#define TEST_NUM 0x20000

/* Declaractions ------------------------------------------------------------------*/
void UartInit(void);

/* Variables ------------------------------------------------------------------*/
uint32_t rec_temp[4];
uint32_t temp[4] = { 0x00};

int main()
{
	SystemInit();//system initialization
	UartInit();//uart0 initialization
	
	printf("\r\n---------------------------------------------------------------------\r\n");
	printf("         GowinSemiconductor Gowin_EMPU(GW1NS-2C) PSRAM Application       \r\n");
	printf("---------------------------------------------------------------------\r\n\r\n");
	
	printf("System Initialized Successfully!\r\n");
	printf("UART0 Initialized Successfully!\r\n");
	
	//Check and wait PSRAM initialization finished
	while(PSRAM_Check_Init_Status()!=1);
	
	printf("PSRAM Initialized Successfully!\r\n");
	
	//Write data into PSRAM
	printf("\r\nWrite Data Into PSRAM : \r\n");
	for(uint32_t i = 0; i < TEST_NUM; i = i+8)
	{
		for(uint16_t j = 0; j < 4; j++)
		{
			temp[j] = i;
			
			printf("The Address 0x%x : Write Data %x.\r\n",i,temp[j]);
		}
		
		PSRAM_Write_Data_Buff(temp,i);
	}
	
	//Read Data From PSRAM
	printf("\r\nRead Data From PSRAM : \r\n");
	for(uint32_t i = 0; i < TEST_NUM; i = i+8)
	{
		PSRAM_Read_Data_Buff(rec_temp,i);
		
		for(uint16_t j = 0; j < 4; j++)
		{
			printf("The Address 0x%x : Read Data %x.\r\n",i,rec_temp[j]);
		}
	}
	
	printf("\r\nGowin_EMPU(GW1NS-2C) PSRAM Application in GMD Finished!\r\n");

	while(1);
}

void UartInit(void)
{
    UART_InitTypeDef UART_InitStruct;
	  
    UART_InitStruct.UART_Mode.UARTMode_Tx = ENABLE;
    UART_InitStruct.UART_Mode.UARTMode_Rx = ENABLE;
    UART_InitStruct.UART_Int.UARTInt_Tx = DISABLE;
    UART_InitStruct.UART_Int.UARTInt_Rx = DISABLE;
    UART_InitStruct.UART_Ovr.UARTOvr_Tx = DISABLE;
    UART_InitStruct.UART_Ovr.UARTOvr_Rx = DISABLE;
    UART_InitStruct.UART_Hstm = DISABLE;
    UART_InitStruct.UART_BaudRate = 115200;//Baud Rate
	  
    UART_Init(UART0,&UART_InitStruct);
}
